"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const errors_1 = require("@oclif/errors");
const chalk_1 = (0, tslib_1.__importDefault)(require("chalk"));
const debug_1 = (0, tslib_1.__importDefault)(require("debug"));
const debug = (0, debug_1.default)('bump-cli:api-client');
class APIError extends errors_1.CLIError {
    constructor(httpError, info = [], exit = 100) {
        var _a, _b;
        const status = (_a = httpError === null || httpError === void 0 ? void 0 : httpError.response) === null || _a === void 0 ? void 0 : _a.status;
        debug(httpError);
        switch ((_b = httpError === null || httpError === void 0 ? void 0 : httpError.response) === null || _b === void 0 ? void 0 : _b.status) {
            case 422:
                [info, exit] = APIError.invalidDefinition(httpError.response.data);
                break;
            case 401:
                [info, exit] = APIError.unauthenticated();
                break;
            case 404:
            case 400:
                [info, exit] = APIError.notFound(httpError.response.data);
                break;
        }
        if (info.length) {
            super(info.join('\n'));
        }
        else {
            super(`Unhandled API error (status: ${status}) (error: ${httpError})`);
        }
        this.exitCode = exit;
        this.http = httpError;
    }
    static is(error) {
        return error instanceof errors_1.CLIError && 'http' in error;
    }
    static notFound(error) {
        const genericMessage = error.message || "It seems the documentation provided doesn't exist.";
        return [
            [
                genericMessage,
                `In a hub context you might want to try the ${chalk_1.default.dim('--auto-create')} flag.\nOtherwise, please check the given ${chalk_1.default.dim('--documentation')}, ${chalk_1.default.dim('--token')} or ${chalk_1.default.dim('--hub')} flags`,
            ],
            104,
        ];
    }
    static invalidDefinition(error) {
        let info = [];
        const genericMessage = error.message || 'Invalid definition file';
        const exit = 122;
        if (error && 'errors' in error) {
            for (const [attr, message] of Object.entries(error.errors)) {
                info = info.concat(APIError.humanAttributeError(attr, message));
            }
        }
        else {
            info.push(genericMessage);
        }
        return [info, exit];
    }
    static humanAttributeError(attribute, messages) {
        let info = [];
        if (messages instanceof Array) {
            const allMessages = messages
                .map((message, idx) => {
                if (message instanceof Object) {
                    return this.humanAttributeError(idx.toString(), message);
                }
                else {
                    return message;
                }
            })
                .join(', ');
            info.push(`${chalk_1.default.underline(attribute)} ${allMessages}`);
        }
        else if (messages instanceof Object) {
            for (const [child, child_messages] of Object.entries(messages)) {
                info = info.concat(this.humanAttributeError(`${attribute}.${child}`, child_messages));
            }
        }
        else if (messages) {
            info.push(`${chalk_1.default.underline(attribute)} ${messages}`);
        }
        return info;
    }
    static unauthenticated() {
        return [
            [
                'You are not allowed to deploy to this documentation.',
                'please check your --token flag or BUMP_TOKEN variable',
            ],
            101,
        ];
    }
}
exports.default = APIError;
