"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIError = exports.BumpApi = void 0;
const tslib_1 = require("tslib");
const axios_1 = (0, tslib_1.__importDefault)(require("axios"));
const vars_1 = require("./vars");
const error_1 = (0, tslib_1.__importDefault)(require("./error"));
exports.APIError = error_1.default;
class BumpApi {
    // Check https://oclif.io/docs/config for details about Config.IConfig
    constructor(config) {
        this.config = config;
        this.getPing = () => {
            return this.client.get('/ping');
        };
        this.getVersion = (versionId, token) => {
            return this.client.get(`/versions/${versionId}`, {
                headers: this.authorizationHeader(token),
            });
        };
        this.postPreview = (body) => {
            return this.client.post('/previews', body);
        };
        this.putPreview = (versionId, body) => {
            return this.client.put(`/previews/${versionId}`, body);
        };
        this.postVersion = (body, token) => {
            return this.client.post('/versions', body, {
                headers: this.authorizationHeader(token),
            });
        };
        this.postDiff = (body) => {
            return this.client.post('/diffs', body);
        };
        this.getDiff = (diffId, format) => {
            return this.client.get(`/diffs/${diffId}`, {
                params: { formats: [format] },
            });
        };
        this.postValidation = (body, token) => {
            return this.client.post('/validations', body, {
                headers: this.authorizationHeader(token),
            });
        };
        this.initializeResponseInterceptor = () => {
            this.client.interceptors.response.use((data) => data, this.handleError);
        };
        this.handleError = (error) => Promise.reject(new error_1.default(error));
        this.authorizationHeader = (token) => {
            return { Authorization: `Basic ${Buffer.from(token).toString('base64')}` };
        };
        const baseURL = `${vars_1.vars.apiUrl}${vars_1.vars.apiBasePath}`;
        const headers = {
            'User-Agent': vars_1.vars.apiUserAgent(config.userAgent),
        };
        this.client = axios_1.default.create({
            baseURL,
            headers,
        });
        this.initializeResponseInterceptor();
    }
}
exports.BumpApi = BumpApi;
(0, tslib_1.__exportStar)(require("./models"), exports);
