"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Deploy = void 0;
const tslib_1 = require("tslib");
const debug_1 = (0, tslib_1.__importDefault)(require("debug"));
const api_1 = require("../api");
class Deploy {
    constructor(config) {
        this._config = config;
    }
    async run(api, dryRun, documentation, token, hub, autoCreate, documentationName, branch) {
        let version = undefined;
        const [definition, references] = api.extractDefinition();
        const request = {
            documentation,
            hub,
            documentation_name: documentationName,
            auto_create_documentation: autoCreate && !dryRun,
            definition,
            references,
            branch_name: branch,
        };
        if (dryRun) {
            await this.validateVersion(request, token);
        }
        else {
            version = await this.createVersion(request, token);
        }
        return version;
    }
    get bumpClient() {
        if (!this._bump)
            this._bump = new api_1.BumpApi(this._config);
        return this._bump;
    }
    async createVersion(request, token) {
        const response = await this.bumpClient.postVersion(request, token);
        let version = undefined;
        switch (response.status) {
            case 204:
                break;
            case 201:
                version = response.data
                    ? response.data
                    : { id: '', doc_public_url: 'https://bump.sh' };
                break;
            default:
                this.d(`API status response was ${response.status}. Expected 201 or 204.`);
                throw new Error('Unexpected server response. Please contact support at https://bump.sh if this error persists');
        }
        return version;
    }
    async validateVersion(version, token) {
        const response = await this.bumpClient.postValidation(version, token);
        switch (response.status) {
            case 200:
                break;
            default:
                this.d(`API status response was ${response.status}. Expected 200.`);
                throw new Error('Unexpected server response. Please contact support at https://bump.sh if this error persists');
        }
        return;
    }
    // Function signature type taken from @types/debug
    // Debugger(formatter: any, ...args: any[]): void;
    /* eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types, @typescript-eslint/no-explicit-any */
    d(formatter, ...args) {
        return (0, debug_1.default)(`bump-cli:core:deploy`)(formatter, ...args);
    }
}
exports.Deploy = Deploy;
