import $RefParser from '@apidevtools/json-schema-ref-parser';
import { JSONSchema4Object, JSONSchema6Object } from 'json-schema';
declare class SupportedFormat {
    static readonly openapi: Record<string, SpecSchema>;
    static readonly asyncapi: Record<string, SpecSchema>;
}
declare class API {
    readonly location: string;
    readonly rawDefinition: string;
    readonly definition: APIDefinition;
    readonly references: APIReference[];
    readonly version: string;
    readonly specName: string;
    readonly spec?: SpecSchema;
    constructor(location: string, $refs: $RefParser.$Refs);
    getSpec(definition: APIDefinition): Record<string, unknown>;
    getSpecName(definition: APIDefinition): string;
    getVersion(definition: APIDefinition): string;
    versionWithoutPatch(): string;
    resolveRelativeLocation(absPath: string): string;
    resolveContent($refs: $RefParser.$Refs): [string, APIDefinition];
    static isOpenAPI(definition: JSONSchema4Object | JSONSchema6Object): definition is OpenAPI;
    static isAsyncAPI(definition: JSONSchema4Object | JSONSchema6Object): definition is AsyncAPI;
    extractDefinition(): [string, APIReference[]];
    static load(path: string): Promise<API>;
}
declare type APIReference = {
    location: string;
    content: string;
};
declare type APIDefinition = OpenAPI | AsyncAPI;
declare type OpenAPI = JSONSchema4Object & {
    readonly openapi?: string;
    readonly swagger?: string;
    readonly info: string;
};
declare type AsyncAPI = JSONSchema4Object & {
    readonly asyncapi: string;
    readonly info: string;
};
export { API, SupportedFormat };
