"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.expires = exports.format = exports.live = exports.failOnBreaking = exports.open = exports.dryRun = exports.filenamePattern = exports.interactive = exports.autoCreate = exports.token = exports.branch = exports.hub = exports.docName = exports.doc = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
// Re-export oclif flags https://oclif.io/docs/flags
(0, tslib_1.__exportStar)(require("@oclif/command/lib/flags"), exports);
// Custom flags for bump-cli
const doc = command_1.flags.build({
    char: 'd',
    description: 'Documentation public id or slug. Can be provided via BUMP_ID environment variable',
    default: () => {
        const envDoc = process.env.BUMP_ID;
        if (envDoc)
            return envDoc;
        // Search doc id in .bump/config.json file?
    },
});
exports.doc = doc;
const docName = command_1.flags.build({
    char: 'n',
    description: 'Documentation name. Used with --auto-create flag.',
    dependsOn: ['auto-create'],
});
exports.docName = docName;
const hub = command_1.flags.build({
    char: 'b',
    description: 'Hub id or slug. Can be provided via BUMP_HUB_ID environment variable',
    default: () => {
        const envHub = process.env.BUMP_HUB_ID;
        if (envHub)
            return envHub;
        // Search hub id in .bump/config.json file?
    },
});
exports.hub = hub;
const filenamePattern = command_1.flags.build({
    description: `Pattern to extract the documentation slug from filenames when deploying a DIRECTORY. Pattern uses only '*' and '{slug}' as special characters to extract the slug from a filename without extension. Used with --hub flag only.`,
    default: '{slug}-api',
});
exports.filenamePattern = filenamePattern;
const branch = command_1.flags.build({
    char: 'B',
    description: 'Branch name. Can be provided via BUMP_BRANCH_NAME environment variable',
    default: () => {
        const envBranch = process.env.BUMP_BRANCH_NAME;
        if (envBranch)
            return envBranch;
    },
});
exports.branch = branch;
const token = command_1.flags.build({
    char: 't',
    required: true,
    description: 'Documentation or Hub token. Can be provided via BUMP_TOKEN environment variable',
    default: () => {
        const envToken = process.env.BUMP_TOKEN;
        if (envToken)
            return envToken;
    },
});
exports.token = token;
const autoCreate = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ description: 'Automatically create the documentation if needed (only available with a --hub flag). Documentation name can be provided with --doc-name flag. Default: false', dependsOn: ['hub'] }, options));
};
exports.autoCreate = autoCreate;
const interactive = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ description: "Interactively create a configuration file to deploy a Hub (only available with a --hub flag). This will start an interactive process if you don't have a CLI configuration file. Default: false", dependsOn: ['hub'] }, options));
};
exports.interactive = interactive;
const dryRun = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ description: 'Validate a new documentation version. Does everything a normal deploy would do except publishing the new version. Useful in automated environments such as test platforms or continuous integration. Default: false' }, options));
};
exports.dryRun = dryRun;
const open = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ char: 'o', default: false }, options));
};
exports.open = open;
const failOnBreaking = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ char: 'F', description: 'Fail when diff contains a breaking change', default: () => {
            const envCi = process.env.CI;
            if (envCi) {
                return true;
            }
            else {
                return false;
            }
        } }, options));
};
exports.failOnBreaking = failOnBreaking;
const live = (options = {}) => {
    return command_1.flags.boolean(Object.assign({ char: 'l', default: false }, options));
};
exports.live = live;
const format = command_1.flags.build({
    char: 'f',
    description: 'Format in which to provide the diff result',
    default: 'text',
    options: ['text', 'markdown', 'json', 'html'],
});
exports.format = format;
const expires = command_1.flags.build({
    char: 'e',
    description: "Specify a longer expiration date for public diffs (defaults to 1 day). Use iso8601 format to provide a date, or you can use `--expires 'never'` to keep the result live indefinitely.",
});
exports.expires = expires;
